@@ -31,6 +31,7 @@
 #include "attachmenthandler.h"
 #include "calendarsupport_debug.h"
 #include "calendarsupport/utils.h"
+#include <kio_version.h>
 
 #include <ItemFetchJob>
 
@@ -49,7 +50,7 @@
 #include <QMimeDatabase>
 #include <QDesktopServices>
 
-using namespace KCalCore;
+using namespace KCalendarCore;
 using namespace Akonadi;
 
 namespace CalendarSupport {
@@ -80,8 +81,7 @@ AttachmentHandler::~AttachmentHandler()
     delete d;
 }
 
-Attachment AttachmentHandler::find(const QString &attachmentName,
-                                   const Incidence::Ptr &incidence)
+Attachment AttachmentHandler::find(const QString &attachmentName, const Incidence::Ptr &incidence)
 {
     if (!incidence) {
         return Attachment();
@@ -110,7 +110,12 @@ Attachment AttachmentHandler::find(const QString &attachmentName,
     }
 
     if (a.isUri()) {
+#if KIO_VERSION < QT_VERSION_CHECK(5, 69, 0)
         auto job = KIO::stat(QUrl(a.uri()), KIO::StatJob::SourceSide, 0);
+#else
+        auto job = KIO::statDetails(QUrl(a.uri()), KIO::StatJob::SourceSide, KIO::StatDetail::Basic);
+#endif
+
         KJobWidgets::setWindow(job, d->mParent);
         if (!job->exec()) {
             KMessageBox::sorry(
@@ -123,8 +128,7 @@ Attachment AttachmentHandler::find(const QString &attachmentName,
     return a;
 }
 
-Attachment AttachmentHandler::find(const QString &attachmentName,
-                                   const ScheduleMessage::Ptr &message)
+Attachment AttachmentHandler::find(const QString &attachmentName, const ScheduleMessage::Ptr &message)
 {
     if (!message) {
         return Attachment();
