@@ -97,8 +97,7 @@ void CalPrinter::setDateRange(const QDate &fd, const QDate &td)
     }
 }
 
-void CalPrinter::print(int type, const QDate &fd, const QDate &td,
-                       const KCalendarCore::Incidence::List &selectedIncidences, bool preview)
+void CalPrinter::print(int type, const QDate &fd, const QDate &td, const KCalendarCore::Incidence::List &selectedIncidences, bool preview)
 {
     PrintPlugin::List::Iterator it;
     const PrintPlugin::List::Iterator end = mPrintPlugins.end();
@@ -129,8 +128,7 @@ void CalPrinter::print(int type, const QDate &fd, const QDate &td,
     }
 }
 
-void CalPrinter::doPrint(PrintPlugin *selectedStyle, CalPrinter::ePrintOrientation dlgorientation,
-                         bool preview)
+void CalPrinter::doPrint(PrintPlugin *selectedStyle, CalPrinter::ePrintOrientation dlgorientation, bool preview)
 {
     if (!selectedStyle) {
         KMessageBox::error(
@@ -177,8 +175,7 @@ void CalPrinter::updateConfig()
 {
 }
 
-CalPrintDialog::CalPrintDialog(int initialPrintType, const PrintPlugin::List &plugins,
-                               QWidget *parent, bool uniqItem)
+CalPrintDialog::CalPrintDialog(int initialPrintType, const PrintPlugin::List &plugins, QWidget *parent, bool uniqItem)
     : QDialog(parent)
 {
     setWindowTitle(i18nc("@title:window", "Print"));
@@ -217,7 +214,7 @@ CalPrintDialog::CalPrintDialog(int initialPrintType, const PrintPlugin::List &pl
     orientationLabel->setAlignment(Qt::AlignRight);
     splitterRightLayout->addWidget(orientationLabel, 1, 0);
 
-    mOrientationSelection = new KComboBox(splitterRight);
+    mOrientationSelection = new QComboBox(splitterRight);
     mOrientationSelection->setToolTip(
         i18nc("@info:tooltip", "Set the print orientation"));
     mOrientationSelection->setWhatsThis(
@@ -236,7 +233,7 @@ CalPrintDialog::CalPrintDialog(int initialPrintType, const PrintPlugin::List &pl
     splitterRightLayout->addWidget(mOrientationSelection, 1, 1);
 
     // signals and slots connections
-    connect(mTypeGroup, QOverload<int>::of(
+    connect(mTypeGroup, QOverload<QAbstractButton *>::of(
                 &QButtonGroup::buttonClicked), this, &CalPrintDialog::setPrintType);
     orientationLabel->setBuddy(mOrientationSelection);
 
@@ -269,7 +266,7 @@ CalPrintDialog::CalPrintDialog(int initialPrintType, const PrintPlugin::List &pl
         if ((firstButton || p->sortID() == initialPrintType) && p->enabled()) {
             firstButton = false;
             radioButton->setChecked(true);
-            setPrintType(id);
+            changePrintType(id);
         }
         mTypeGroup->addButton(radioButton, mapit.key());
         typeLayout->addWidget(radioButton);
@@ -296,7 +293,7 @@ void CalPrintDialog::setPreview(bool preview)
     }
 }
 
-void CalPrintDialog::setPrintType(int i)
+void CalPrintDialog::changePrintType(int i)
 {
     mConfigArea->setCurrentIndex(i);
     mConfigArea->currentWidget()->raise();
@@ -306,6 +303,16 @@ void CalPrintDialog::setPrintType(int i)
     }
 }
 
+void CalPrintDialog::setPrintType(QAbstractButton *button)
+{
+    if (button) {
+        const int i = mTypeGroup->id(button);
+        mConfigArea->setCurrentIndex(i);
+        mConfigArea->currentWidget()->raise();
+        button->setChecked(true);
+    }
+}
+
 void CalPrintDialog::setOrientation(CalPrinter::ePrintOrientation orientation)
 {
     mOrientation = orientation;
