@@ -34,9 +34,11 @@
 #include <AkonadiCore/AgentInstance>
 #include <AkonadiCore/AgentManager>
 #include <AkonadiCore/EntityDisplayAttribute>
+
+#include <Akonadi/Calendar/BlockAlarmsAttribute>
 #include <Akonadi/Calendar/ETMCalendar>
 #include <Akonadi/Calendar/PublishDialog>
-#include <akonadi/calendar/calendarsettings.h>
+#include <akonadi/calendar/calendarsettings.h> //krazy:exclude=camelcase it's a generated file
 
 #include <KHolidays/HolidayRegion>
 
@@ -56,9 +58,9 @@
 
 #include <KMessageBox>
 #include <KIO/FileCopyJob>
-#include <KIconLoader>
 #include <KLocalizedString>
 
+#include <QApplication>
 #include <QUrl>
 #include <QAbstractItemModel>
 #include <QDrag>
@@ -69,6 +71,7 @@
 #include <QUrlQuery>
 #include <QRegularExpression>
 #include <QTimeZone>
+#include <QStyle>
 
 #include "calendarsupport_debug.h"
 
@@ -271,9 +274,9 @@ QDrag *CalendarSupport::createDrag(const Akonadi::Item::List &items, QWidget *pa
 
     const QByteArray common = findMostCommonType(items);
     if (common == "Event") {
-        drag->setPixmap(BarIcon(QStringLiteral("view-calendar-day")));
+        drag->setPixmap(QIcon::fromTheme(QStringLiteral("view-calendar-day")).pixmap(qApp->style()->pixelMetric(QStyle::PM_ToolBarIconSize)));
     } else if (common == "Todo") {
-        drag->setPixmap(BarIcon(QStringLiteral("view-calendar-tasks")));
+        drag->setPixmap(QIcon::fromTheme(QStringLiteral("view-calendar-tasks")).pixmap(qApp->style()->pixelMetric(QStyle::PM_ToolBarIconSize)));
     }
 
     return drag.release();
@@ -291,8 +294,7 @@ static bool itemMatches(const Akonadi::Item &item, const KCalendarCore::CalFilte
     return filter->filterIncidence(inc);
 }
 
-Akonadi::Item::List CalendarSupport::applyCalFilter(const Akonadi::Item::List &items_,
-                                                    const KCalendarCore::CalFilter *filter)
+Akonadi::Item::List CalendarSupport::applyCalFilter(const Akonadi::Item::List &items_, const KCalendarCore::CalFilter *filter)
 {
     Q_ASSERT(filter);
     Akonadi::Item::List items(items_);
@@ -302,8 +304,7 @@ Akonadi::Item::List CalendarSupport::applyCalFilter(const Akonadi::Item::List &i
     return items;
 }
 
-bool CalendarSupport::isValidIncidenceItemUrl(const QUrl &url,
-                                              const QStringList &supportedMimeTypes)
+bool CalendarSupport::isValidIncidenceItemUrl(const QUrl &url, const QStringList &supportedMimeTypes)
 {
     if (!url.isValid()) {
         return false;
@@ -412,12 +413,10 @@ KCalendarCore::Incidence::List CalendarSupport::incidences(const QMimeData *mime
     return incidences;
 }
 
-Akonadi::Collection CalendarSupport::selectCollection(QWidget *parent, int &dialogCode,
-                                                      const QStringList &mimeTypes,
-                                                      const Akonadi::Collection &defCollection)
+Akonadi::Collection CalendarSupport::selectCollection(QWidget *parent, int &dialogCode, const QStringList &mimeTypes, const Akonadi::Collection &defCollection)
 {
     QPointer<Akonadi::CollectionDialog> dlg(new Akonadi::CollectionDialog(parent));
-    dlg->setWindowTitle(i18n("Select Calendar"));
+    dlg->setWindowTitle(i18nc("@title:window", "Select Calendar"));
     dlg->setDescription(i18n("Select the calendar where this item will be stored."));
     dlg->changeCollectionDialogOptions(Akonadi::CollectionDialog::KeepTreeExpanded);
     qCDebug(CALENDARSUPPORT_LOG) << "selecting collections with mimeType in " << mimeTypes;
@@ -450,9 +449,7 @@ Akonadi::Item CalendarSupport::itemFromIndex(const QModelIndex &idx)
     return item;
 }
 
-Akonadi::Collection::List CalendarSupport::collectionsFromModel(const QAbstractItemModel *model,
-                                                                const QModelIndex &parentIndex,
-                                                                int start, int end)
+Akonadi::Collection::List CalendarSupport::collectionsFromModel(const QAbstractItemModel *model, const QModelIndex &parentIndex, int start, int end)
 {
     const int endRow = end >= 0 ? end : model->rowCount(parentIndex) - 1;
     Akonadi::Collection::List collections;
@@ -473,9 +470,7 @@ Akonadi::Collection::List CalendarSupport::collectionsFromModel(const QAbstractI
     return collections;
 }
 
-Akonadi::Item::List CalendarSupport::itemsFromModel(const QAbstractItemModel *model,
-                                                    const QModelIndex &parentIndex, int start,
-                                                    int end)
+Akonadi::Item::List CalendarSupport::itemsFromModel(const QAbstractItemModel *model, const QModelIndex &parentIndex, int start, int end)
 {
     const int endRow = end >= 0 ? end : model->rowCount(parentIndex) - 1;
     Akonadi::Item::List items;
@@ -530,7 +525,7 @@ QString CalendarSupport::displayName(Akonadi::ETMCalendar *calendar, const Akona
     const QString resourceName = fullCollection.resource();
 
     // Kolab Groupware
-    if (resourceName.contains(QStringLiteral("kolab"))) {
+    if (resourceName.contains(QLatin1String("kolab"))) {
         QString typeStr = cName; // contents type: "Calendar", "Tasks", etc
         QString ownerStr;        // folder owner: "fred", "ethel", etc
         QString nameStr;         // folder name: "Public", "Test", etc
@@ -544,8 +539,8 @@ QString CalendarSupport::displayName(Akonadi::ETMCalendar *calendar, const Akona
                     nameStr = cName;
                     typeStr = i18n("Calendar");
                     break;
-                } else if (tName.startsWith(QLatin1String("shared.tasks"), Qt::CaseInsensitive) ||
-                           tName.startsWith(QLatin1String("shared.todo"), Qt::CaseInsensitive)) {
+                } else if (tName.startsWith(QLatin1String("shared.tasks"), Qt::CaseInsensitive)
+                           || tName.startsWith(QLatin1String("shared.todo"), Qt::CaseInsensitive)) {
                     ownerStr = QStringLiteral("Shared");
                     nameStr = cName;
                     typeStr = i18n("Tasks");
@@ -560,10 +555,10 @@ QString CalendarSupport::displayName(Akonadi::ETMCalendar *calendar, const Akona
                     nameStr = cName;
                     typeStr = i18n("Notes");
                     break;
-                } else if (tName != i18n("Calendar") &&
-                           tName != i18n("Tasks") &&
-                           tName != i18n("Journal") &&
-                           tName != i18n("Notes")) {
+                } else if (tName != i18n("Calendar")
+                           && tName != i18n("Tasks")
+                           && tName != i18n("Journal")
+                           && tName != i18n("Notes")) {
                     ownerStr = tName;
                     break;
                 } else {
@@ -578,9 +573,9 @@ QString CalendarSupport::displayName(Akonadi::ETMCalendar *calendar, const Akona
             if (!ownerStr.compare(QLatin1String("INBOX"), Qt::CaseInsensitive)) {
                 return i18nc("%1 is folder contents",
                              "My Kolab %1", typeStr);
-            } else if (!ownerStr.compare(QLatin1String("SHARED"), Qt::CaseInsensitive) ||
-                       !ownerStr.compare(QLatin1String("CALENDAR"), Qt::CaseInsensitive) ||
-                       !ownerStr.compare(QLatin1String("RESOURCES"), Qt::CaseInsensitive)) {
+            } else if (!ownerStr.compare(QLatin1String("SHARED"), Qt::CaseInsensitive)
+                       || !ownerStr.compare(QLatin1String("CALENDAR"), Qt::CaseInsensitive)
+                       || !ownerStr.compare(QLatin1String("RESOURCES"), Qt::CaseInsensitive)) {
                 return i18nc("%1 is folder name, %2 is folder contents",
                              "Shared Kolab %1 %2", nameStr, typeStr);
             } else {
@@ -600,7 +595,7 @@ QString CalendarSupport::displayName(Akonadi::ETMCalendar *calendar, const Akona
     } //end kolab section
 
     // Dav Groupware
-    if (resourceName.contains(QStringLiteral("davgroupware"))) {
+    if (resourceName.contains(QLatin1String("davgroupware"))) {
         const QString resourceDisplayName
             = Akonadi::AgentManager::self()->instance(resourceName).name();
         return i18nc("%1 is the folder name", "%1 in %2",
@@ -608,7 +603,7 @@ QString CalendarSupport::displayName(Akonadi::ETMCalendar *calendar, const Akona
     } //end caldav section
 
     // Google
-    if (resourceName.contains(QStringLiteral("google"))) {
+    if (resourceName.contains(QLatin1String("google"))) {
         QString ownerStr;        // folder owner: "user@gmail.com"
         if (calendar) {
             Akonadi::Collection p = c.parentCollection();
@@ -619,13 +614,13 @@ QString CalendarSupport::displayName(Akonadi::ETMCalendar *calendar, const Akona
 
         QString typeStr;
         const QString mimeStr = c.contentMimeTypes().join(QLatin1Char(','));
-        if (mimeStr.contains(QStringLiteral(".event"))) {
+        if (mimeStr.contains(QLatin1String(".event"))) {
             typeStr = i18n("Calendar");
-        } else if (mimeStr.contains(QStringLiteral(".todo"))) {
+        } else if (mimeStr.contains(QLatin1String(".todo"))) {
             typeStr = i18n("Tasks");
-        } else if (mimeStr.contains(QStringLiteral(".journal"))) {
+        } else if (mimeStr.contains(QLatin1String(".journal"))) {
             typeStr = i18n("Journal");
-        } else if (mimeStr.contains(QStringLiteral(".note"))) {
+        } else if (mimeStr.contains(QLatin1String(".note"))) {
             typeStr = i18n("Notes");
         } else {
             typeStr = mimeStr;
@@ -654,7 +649,7 @@ QString CalendarSupport::displayName(Akonadi::ETMCalendar *calendar, const Akona
 
     if (!dName.isEmpty()) {
         return fullCollection.name().startsWith(QLatin1String("akonadi_")) ? i18n("My %1",
-                                                                                   dName) : dName;
+                                                                                  dName) : dName;
     } else if (!fullCollection.name().isEmpty()) {
         return fullCollection.name();
     } else {
@@ -677,21 +672,41 @@ QString CalendarSupport::toolTipString(const Akonadi::Collection &coll, bool ric
     if (displayName.isEmpty()) {
         displayName = coll.name();
     }
+    if (coll.id() == CalendarSupport::KCalPrefs::instance()->defaultCalendarId()) {
+        displayName = i18nc("this is the default calendar", "%1 (Default Calendar)", displayName);
+    }
     str += QLatin1String("<b>") + displayName + QLatin1String("</b>");
     str += QLatin1String("<hr>");
 
     // Calendar Type
     QString calendarType;
     if (!coll.isVirtual()) {
-        const Akonadi::AgentInstance instance =
-            Akonadi::AgentManager::self()->instance(coll.resource());
+        const Akonadi::AgentInstance instance
+            = Akonadi::AgentManager::self()->instance(coll.resource());
         calendarType = instance.type().name();
     } else {
-        calendarType = i18nc("unknown calendar type", "unknown");
+        calendarType = i18nc("a virtual folder type", "Virtual");
     }
-    str += QLatin1String("<i>") + i18n("Calendar type:") + QLatin1String("</i>");
+    str += QLatin1String("<i>") + i18n("Folder type:") + QLatin1String("</i>");
     str += QLatin1String("&nbsp;") + calendarType;
 
+    // Content Type
+    QStringList mimeTypes = coll.contentMimeTypes();
+    mimeTypes.removeAll(QLatin1String("inode/directory"));
+    QString mimeTypeStr;
+    if (!mimeTypes.isEmpty()) {
+        mimeTypeStr = QLocale().createSeparatedList(
+                          mimeTypes.
+                          replaceInStrings(
+                              QLatin1String("application/x-vnd.akonadi.calendar."), QString()));
+    } else {
+        mimeTypeStr = i18nc("collection has no mimetypes to show the user", "none");
+    }
+    str += QLatin1String("<br>");
+    str += QLatin1String("<i>") + i18n("Content type:") + QLatin1String("</i>");
+    str += QLatin1String("&nbsp;") + mimeTypeStr;
+    str += QLatin1String("</br>");
+
     // Read only?
     bool isReadOnly = !(coll.rights() & Akonadi::Collection::CanChangeItem);
     str += QLatin1String("<br>");
@@ -704,9 +719,36 @@ QString CalendarSupport::toolTipString(const Akonadi::Collection &coll, bool ric
     }
     str += QLatin1String("</br>");
 
+    // Blocking reminders?
+    QStringList blockList;
+    if (coll.hasAttribute<Akonadi::BlockAlarmsAttribute>()) {
+        if (coll.attribute<Akonadi::BlockAlarmsAttribute>()->isEverythingBlocked()) {
+            blockList << i18nc("blocking all reminders for this calendar", "all");
+        } else {
+            if (coll.attribute<Akonadi::BlockAlarmsAttribute>()->isAlarmTypeBlocked(Alarm::Audio)) {
+                blockList << i18nc("blocking audio reminders for this calendar", "audio");
+            } else if (coll.attribute<Akonadi::BlockAlarmsAttribute>()->isAlarmTypeBlocked(Alarm::Display)) {
+                blockList << i18nc("blocking display pop-up dialog reminders for this calendar", "display");
+            } else if (coll.attribute<Akonadi::BlockAlarmsAttribute>()->isAlarmTypeBlocked(Alarm::Email)) {
+                blockList << i18nc("blocking email reminders for this calendar", "email");
+            } else if (coll.attribute<Akonadi::BlockAlarmsAttribute>()->isAlarmTypeBlocked(Alarm::Procedure)) {
+                blockList << i18nc("blocking run a command reminders for this calendar", "procedure");
+            } else {
+                blockList << i18nc("blocking unknown type reminders for this calendar", "other");
+            }
+        }
+    } else {
+        blockList << i18nc("not blocking any reminder types for this calendar", "none");
+    }
+    str += QLatin1String("<br>");
+    str += QLatin1String("<i>") + i18n("Blocked Reminders:") + QLatin1String("</i>");
+    str += QLatin1String("&nbsp;");
+    str += QLocale().createSeparatedList(blockList);
+    str += QLatin1String("</br>");
+
     str += QLatin1String("</qt>");
     return str;
- }
+}
 
 QString CalendarSupport::subMimeTypeForIncidence(const KCalendarCore::Incidence::Ptr &incidence)
 {
@@ -808,8 +850,7 @@ QStringList CalendarSupport::categories(const KCalendarCore::Incidence::List &in
     return cats;
 }
 
-bool CalendarSupport::mergeCalendar(const QString &srcFilename,
-                                    const KCalendarCore::Calendar::Ptr &destCalendar)
+bool CalendarSupport::mergeCalendar(const QString &srcFilename, const KCalendarCore::Calendar::Ptr &destCalendar)
 {
     if (srcFilename.isEmpty()) {
         qCCritical(CALENDARSUPPORT_LOG) << "Empty filename.";
@@ -829,3 +870,27 @@ bool CalendarSupport::mergeCalendar(const QString &srcFilename,
 
     return loadedSuccesfully;
 }
+
+void CalendarSupport::createAlarmReminder(const Alarm::Ptr &alarm, KCalendarCore::IncidenceBase::IncidenceType type)
+{
+    int duration; // in secs
+    switch (CalendarSupport::KCalPrefs::instance()->mReminderTimeUnits) {
+    default:
+    case 0: // mins
+        duration = CalendarSupport::KCalPrefs::instance()->mReminderTime * 60;
+        break;
+    case 1: // hours
+        duration = CalendarSupport::KCalPrefs::instance()->mReminderTime * 60 * 60;
+        break;
+    case 2: // days
+        duration = CalendarSupport::KCalPrefs::instance()->mReminderTime * 60 * 60 * 24;
+        break;
+    }
+    alarm->setType(KCalendarCore::Alarm::Display);
+    alarm->setEnabled(true);
+    if (type == KCalendarCore::Incidence::TypeEvent) {
+        alarm->setStartOffset(KCalendarCore::Duration(-duration));
+    } else {
+        alarm->setEndOffset(KCalendarCore::Duration(-duration));
+    }
+}
